@@ -118,8 +118,8 @@ def pmax(x, y):
         if numpy_ma_isMA(y):
             # x and y are both masked
             z = numpy_maximum(x, y)
-            z = numpy_ma_where(x.mask & -y.mask, y, z)
-            x = numpy_ma_where(y.mask & -x.mask, x, z)
+            z = numpy_ma_where(x.mask & ~y.mask, y, z)
+            x = numpy_ma_where(y.mask & ~x.mask, x, z)
             if x.mask is numpy_ma_nomask: #not numpy_any(x.mask):
                 x = numpy_array(x)
         else:
@@ -166,8 +166,8 @@ def pmin(x, y):
         if numpy_ma_isMA(y):
             # x and y are both masked
             z = numpy_minimum(x, y)
-            z = numpy_ma_where(x.mask & -y.mask, y, z)
-            x = numpy_ma_where(y.mask & -x.mask, x, z)
+            z = numpy_ma_where(x.mask & ~y.mask, y, z)
+            x = numpy_ma_where(y.mask & ~x.mask, x, z)
             if x.mask is numpy_ma_nomask:
                 x = numpy_array(x)
         else:
@@ -575,7 +575,7 @@ def sample_size_f(a, axis=None, masked=False):
         non-negative
 '''
     if masked:        
-        N = numpy_sum(-a.mask, axis=axis, dtype=float)
+        N = numpy_sum(~a.mask, axis=axis, dtype=float)
         if not numpy_ndim(N):
             N = numpy_asanyarray(N)
     else:
