@@ -1409,7 +1409,9 @@ def _create_bounded_item(nc, ncvar, attributes, f, dimension=False,
             bounds.transpose(iaxes, i=True)
     #--- End: if
 
-    c.insert_data(data, bounds=bounds, copy=False)
+    c.insert_data(data, copy=False)
+    if bounds:
+        c.insert_bounds(bounds, copy=False)
 
     # ---------------------------------------------------------
     # Return the bounded variable
